@@ -1,3 +1,5 @@
+import logging
+
 import dcclog
 from dcclog.cipher.rsa import RSAEncryption
 
@@ -7,6 +9,7 @@ dcclog.default_config(
     cipher=RSAEncryption("pubkey.pem"),
 )
 logger = dcclog.getLogger(name=__name__)
+logging.basicConfig()
 
 logger.error("error message.")
 logger.warning("warning message.")
